@@ -22,24 +22,24 @@ TODO. (It returns a video tag for now)
 
 sub to_embed {
   my $self = shift;
-  my $url = $self->url;
+  my $url  = $self->url;
   my $type = $url->path =~ /\.(\w+)$/ ? $1 : 'unknown';
   my %args = @_;
   my @extra;
 
   $type = $self->_types->type($type) || "unknown/$type";
   $args{height} ||= $self->DEFAULT_VIDEO_HEIGHT;
-  $args{width} ||= $self->DEFAULT_VIDEO_WIDTH;
+  $args{width}  ||= $self->DEFAULT_VIDEO_WIDTH;
 
   local $" = ' ';
   push @extra, 'autoplay' if $args{autoplay};
   push @extra, 'controls' if $args{controls};
   unshift @extra, '' if @extra;
 
-   qq(<video width="$args{width}" height="$args{height}"@extra>)
-  .qq(<source src="$url" type="$type">)
-  .qq(<p class="alert">Your browser does not support the video tag.</p>)
-  .qq(</video>)
+  qq(<video width="$args{width}" height="$args{height}"@extra>)
+    . qq(<source src="$url" type="$type">)
+    . qq(<p class="alert">Your browser does not support the video tag.</p>)
+    . qq(</video>);
 }
 
 =head1 AUTHOR
