@@ -1,8 +1,8 @@
-package
-  t::App;
+package t::App;
 
 use strict;
 use warnings;
+use Mojolicious;
 use Test::Mojo;
 use Test::More;
 
@@ -10,25 +10,22 @@ my $t;
 
 sub make_app {
   my $class = shift;
+  my $app   = Mojolicious->new;
 
-  eval <<'  APP' or die $@;
-    use Mojolicious::Lite;
-    plugin LinkEmbedder => { route => '/embed' };
-    app->start;
-  APP
+  $app->plugin(LinkEmbedder => {route => '/embed'});
 
-  Test::Mojo->new;
+  Test::Mojo->new($app);
 }
 
 sub import {
-  my $class = shift;
+  my $class  = shift;
   my $caller = caller;
 
   strict->import;
   warnings->import;
 
   no strict 'refs';
-  *{ "$caller\::t" } = \ $class->make_app;
+  *{"$caller\::t"} = \$class->make_app;
 }
 
 1;
